@@ -4,4 +4,4 @@ from .stats import mean, stdev, calc_prob, calculate_class_probabilities
 from .trig import sin, cos, tan, cot, csc, sec
 from .cosine_sim import cosine_sim
 from .sigmoid import sigmoid
-from .gaussain import gaussian
\ No newline at end of file
+from .gaussain import *
\ No newline at end of file
