@@ -20,14 +20,11 @@ def mul(num1, num2):
 def div(num1, num2):
     return num1 / num2
 
-def fac(num1):
-    num_list = []
-    y = 1
-    for i in range(1, int(num1) + 1):
-        num_list.append(i)
-    for x in num_list:
-        num1 = num1 * x
-    return num1
+
+
+
+def fac(n):
+	return 1 if (n==1 or n==0) else n * fac(n - 1);
 
 def sqrt(num1):
     assert num1 >= 0, "Can't take the square root of negative numbers"
